@@ -1,5 +1,6 @@
 CxxFlags <- function(as_character = FALSE) {
-  CXXFLAGS <- "-D_REENTRANT -DSTAN_THREADS"
+  TBB <- system.file("include", package = "RcppParallel", mustWork = TRUE)
+  CXXFLAGS <- paste0("-I", shQuote(TBB), " -D_REENTRANT -DSTAN_THREADS")
   if (isTRUE(as_character)) return(CXXFLAGS)
   cat(CXXFLAGS, " ")
   return(invisible(NULL))
@@ -7,7 +8,7 @@ CxxFlags <- function(as_character = FALSE) {
 
 LdFlags <- function(as_character = FALSE) {
   TBB <- system.file("lib", .Platform$r_arch, package = "RcppParallel", mustWork = TRUE)
-  PKG_LIBS <- paste0("-L", shQuote(TBB), " -Wl,-rpath ", TBB, " -ltbb -ltbbmalloc")
+  PKG_LIBS <- paste0("-L", shQuote(TBB), " -Wl,-rpath,", TBB, " -ltbb -ltbbmalloc")
   if (isTRUE(as_character)) return(PKG_LIBS)
   cat(PKG_LIBS, " ")
   return(invisible(NULL))
