@@ -1,6 +1,7 @@
 #ifndef STAN_MATH_PRIM_SCAL_META_IS_VAR_OR_ARITHMETIC_HPP
 #define STAN_MATH_PRIM_SCAL_META_IS_VAR_OR_ARITHMETIC_HPP
 
+#include <stan/math/prim/scal/meta/bool_constant.hpp>
 #include <stan/math/prim/scal/meta/is_var.hpp>
 #include <stan/math/prim/scal/meta/scalar_type.hpp>
 #include <stan/math/prim/scal/meta/conjunction.hpp>
@@ -9,17 +10,15 @@
 namespace stan {
 
 /**
- * Defines a public enum named value which is defined to be true (1)
- * if the type is either var or an aritmetic type
- * and false (0) otherwise.
+ * Defines a static member value which is defined to be true (1)
+ * if the unqualified cv of type T or if a container it's underlying type
+   is either var or an aritmetic type and false (0) otherwise.
  */
 template <typename T>
-struct is_var_or_arithmetic_type {
-  enum {
-    value = (is_var<typename scalar_type<T>::type>::value
-             || std::is_arithmetic<typename scalar_type<T>::type>::value)
-  };
-};
+struct is_var_or_arithmetic_type
+    : bool_constant<(
+          is_var<scalar_type_t<std::decay_t<T>>>::value
+          || std::is_arithmetic<scalar_type_t<std::decay_t<T>>>::value)> {};
 
 /**
  * Extends std::true_type if all the provided types are either var or
