@@ -1,10 +1,10 @@
 #ifndef STAN_MATH_REV_SCAL_FUN_EXP2_HPP
 #define STAN_MATH_REV_SCAL_FUN_EXP2_HPP
 
+#include <stan/math/rev/meta.hpp>
 #include <stan/math/rev/core.hpp>
 #include <stan/math/prim/scal/fun/constants.hpp>
 #include <cmath>
-#include <valarray>
 
 namespace stan {
 namespace math {
@@ -12,7 +12,7 @@ namespace math {
 namespace internal {
 class exp2_vari : public op_v_vari {
  public:
-  explicit exp2_vari(vari* avi) : op_v_vari(std::pow(2.0, avi->val_), avi) {}
+  explicit exp2_vari(vari* avi) : op_v_vari(std::exp2(avi->val_), avi) {}
   void chain() { avi_->adj_ += adj_ * val_ * LOG_2; }
 };
 }  // namespace internal
