@@ -1,8 +1,9 @@
 #ifndef STAN_MATH_REV_SCAL_FUN_FMOD_HPP
 #define STAN_MATH_REV_SCAL_FUN_FMOD_HPP
 
+#include <stan/math/rev/meta.hpp>
 #include <stan/math/rev/core.hpp>
-#include <stan/math/prim/scal/fun/is_nan.hpp>
+#include <stan/math/prim/scal/fun/is_any_nan.hpp>
 #include <cmath>
 #include <limits>
 
@@ -15,7 +16,7 @@ class fmod_vv_vari : public op_vv_vari {
   fmod_vv_vari(vari* avi, vari* bvi)
       : op_vv_vari(std::fmod(avi->val_, bvi->val_), avi, bvi) {}
   void chain() {
-    if (unlikely(is_nan(avi_->val_) || is_nan(bvi_->val_))) {
+    if (unlikely(is_any_nan(avi_->val_, bvi_->val_))) {
       avi_->adj_ = std::numeric_limits<double>::quiet_NaN();
       bvi_->adj_ = std::numeric_limits<double>::quiet_NaN();
     } else {
@@ -30,10 +31,11 @@ class fmod_vd_vari : public op_vd_vari {
   fmod_vd_vari(vari* avi, double b)
       : op_vd_vari(std::fmod(avi->val_, b), avi, b) {}
   void chain() {
-    if (unlikely(is_nan(avi_->val_) || is_nan(bd_)))
+    if (unlikely(is_any_nan(avi_->val_, bd_))) {
       avi_->adj_ = std::numeric_limits<double>::quiet_NaN();
-    else
+    } else {
       avi_->adj_ += adj_;
+    }
   }
 };
 
@@ -42,7 +44,7 @@ class fmod_dv_vari : public op_dv_vari {
   fmod_dv_vari(double a, vari* bvi)
       : op_dv_vari(std::fmod(a, bvi->val_), a, bvi) {}
   void chain() {
-    if (unlikely(is_nan(bvi_->val_) || is_nan(ad_))) {
+    if (unlikely(is_any_nan(bvi_->val_, ad_))) {
       bvi_->adj_ = std::numeric_limits<double>::quiet_NaN();
     } else {
       int d = static_cast<int>(ad_ / bvi_->val_);
