@@ -1,9 +1,9 @@
 #ifndef STAN_MATH_REV_SCAL_FUN_IS_INF_HPP
 #define STAN_MATH_REV_SCAL_FUN_IS_INF_HPP
 
+#include <stan/math/rev/meta.hpp>
 #include <stan/math/rev/core.hpp>
 #include <stan/math/prim/scal/fun/is_inf.hpp>
-#include <stan/math/prim/scal/fun/constants.hpp>
 
 namespace stan {
 namespace math {
